@@ -125,6 +125,8 @@ do
        new=`echo "$new" |perl -pi -e 's!KFileMetaData/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KCalendarCore/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KDeclarative/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KUserFeedback/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KAlarmCal/!!g'`;
        newname=`echo "$new" |perl -pi -e 's!.h!!'`;
 
        #echo "before go : $new";
